"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayrollCompanyTaxesTypeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The tax name"""
    employer: NotRequired[bool]
    r"""Whether this tax is an employer or employee tax"""
    amount: NotRequired[str]
    r"""The amount of this tax for the payroll"""


class PayrollCompanyTaxesType(BaseModel):
    name: Optional[str] = None
    r"""The tax name"""

    employer: Optional[bool] = None
    r"""Whether this tax is an employer or employee tax"""

    amount: Optional[str] = None
    r"""The amount of this tax for the payroll"""
