"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyMlkDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenth(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyLaborDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyThanksgiving(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDayTypedDict(TypedDict):
    selected: NotRequired[bool]


class PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDay(BaseModel):
    selected: Optional[bool] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict(TypedDict):
    r"""An object containing federal holiday objects, each containing a boolean selected property."""

    new_years_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDayTypedDict
    ]
    mlk_day: NotRequired[PutCompaniesCompanyUUIDHolidayPayPolicyMlkDayTypedDict]
    presidents_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDayTypedDict
    ]
    memorial_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDayTypedDict
    ]
    juneteenth: NotRequired[PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenthTypedDict]
    independence_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDayTypedDict
    ]
    labor_day: NotRequired[PutCompaniesCompanyUUIDHolidayPayPolicyLaborDayTypedDict]
    columbus_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDayTypedDict
    ]
    veterans_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDayTypedDict
    ]
    thanksgiving: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyThanksgivingTypedDict
    ]
    christmas_day: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDayTypedDict
    ]


class PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays(BaseModel):
    r"""An object containing federal holiday objects, each containing a boolean selected property."""

    new_years_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyNewYearsDay] = None

    mlk_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyMlkDay] = None

    presidents_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyPresidentsDay] = (
        None
    )

    memorial_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyMemorialDay] = None

    juneteenth: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyJuneteenth] = None

    independence_day: Optional[
        PutCompaniesCompanyUUIDHolidayPayPolicyIndependenceDay
    ] = None

    labor_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyLaborDay] = None

    columbus_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyColumbusDay] = None

    veterans_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyVeteransDay] = None

    thanksgiving: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyThanksgiving] = None

    christmas_day: Optional[PutCompaniesCompanyUUIDHolidayPayPolicyChristmasDay] = None


class PutCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict(TypedDict):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    federal_holidays: NotRequired[
        PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidaysTypedDict
    ]
    r"""An object containing federal holiday objects, each containing a boolean selected property."""


class PutCompaniesCompanyUUIDHolidayPayPolicyRequestBody(BaseModel):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    federal_holidays: Optional[
        PutCompaniesCompanyUUIDHolidayPayPolicyFederalHolidays
    ] = None
    r"""An object containing federal holiday objects, each containing a boolean selected property."""


class PutCompaniesCompanyUUIDHolidayPayPolicyRequestTypedDict(TypedDict):
    company_uuid: str
    r"""The UUID of the company"""
    request_body: PutCompaniesCompanyUUIDHolidayPayPolicyRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutCompaniesCompanyUUIDHolidayPayPolicyRequest(BaseModel):
    company_uuid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the company"""

    request_body: Annotated[
        PutCompaniesCompanyUUIDHolidayPayPolicyRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""
