"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateReportTypedDict(TypedDict):
    r"""Example response"""

    request_uuid: NotRequired[str]
    r"""A unique identifier of the report request"""
    company_uuid: NotRequired[str]
    r"""Company UUID"""
    custom_name: NotRequired[str]
    r"""Title of the report"""
    file_type: NotRequired[str]
    r"""File type"""


class CreateReport(BaseModel):
    r"""Example response"""

    request_uuid: Optional[str] = None
    r"""A unique identifier of the report request"""

    company_uuid: Optional[str] = None
    r"""Company UUID"""

    custom_name: Optional[str] = None
    r"""Title of the report"""

    file_type: Optional[str] = None
    r"""File type"""
