"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddressTypedDict(TypedDict):
    street_1: NotRequired[str]
    street_2: NotRequired[str]
    city: NotRequired[str]
    state: NotRequired[str]
    zip_code: NotRequired[str]


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddress(BaseModel):
    street_1: Optional[str] = None

    street_2: Optional[str] = None

    city: Optional[str] = None

    state: Optional[str] = None

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zip")] = None


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBodyTypedDict(TypedDict):
    version: NotRequired[str]
    r"""The current version of the object. See the versioning guide for information on how to use this field."""
    first_name: NotRequired[str]
    middle_initial: NotRequired[str]
    last_name: NotRequired[str]
    title: NotRequired[str]
    phone: NotRequired[str]
    birthday: NotRequired[str]
    ssn: NotRequired[str]
    home_address: NotRequired[
        PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddressTypedDict
    ]


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBody(BaseModel):
    version: Optional[str] = None
    r"""The current version of the object. See the versioning guide for information on how to use this field."""

    first_name: Optional[str] = None

    middle_initial: Optional[str] = None

    last_name: Optional[str] = None

    title: Optional[str] = None

    phone: Optional[str] = None

    birthday: Optional[str] = None

    ssn: Optional[str] = None

    home_address: Optional[
        PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDHomeAddress
    ] = None


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestTypedDict(TypedDict):
    company_uuid: str
    r"""The UUID of the company"""
    signatory_uuid: str
    r"""The UUID of the signatory"""
    request_body: PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequest(BaseModel):
    company_uuid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the company"""

    signatory_uuid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the signatory"""

    request_body: Annotated[
        PutV1CompaniesCompanyUUIDSignatoriesSignatoryUUIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""
