"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AccruingTimeOffHourTypedDict(TypedDict):
    r"""The representation of an unprocessed termination pay period."""

    time_off_policy_uuid: NotRequired[str]
    r"""A unique identifier of the time off policy."""
    hours: NotRequired[str]
    r"""Hours accrued during this pay period."""


class AccruingTimeOffHour(BaseModel):
    r"""The representation of an unprocessed termination pay period."""

    time_off_policy_uuid: Optional[str] = None
    r"""A unique identifier of the time off policy."""

    hours: Optional[str] = None
    r"""Hours accrued during this pay period."""
