"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ReportTypedDict(TypedDict):
    r"""Example response"""

    request_uuid: NotRequired[str]
    r"""A unique identifier of the report request"""
    status: NotRequired[str]
    r"""Current status of the report, possible values are 'succeeded', 'pending', or 'failed'"""
    report_urls: NotRequired[List[str]]
    r"""The array of urls to access the report"""


class Report(BaseModel):
    r"""Example response"""

    request_uuid: Optional[str] = None
    r"""A unique identifier of the report request"""

    status: Optional[str] = None
    r"""Current status of the report, possible values are 'succeeded', 'pending', or 'failed'"""

    report_urls: Optional[List[str]] = None
    r"""The array of urls to access the report"""
