"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PaymentConfigsTypedDict(TypedDict):
    r"""Example response"""

    company_uuid: NotRequired[str]
    r"""Company uuid"""
    partner_uuid: NotRequired[str]
    r"""Partner uuid"""
    fast_payment_limit: NotRequired[str]
    r"""Payment limit for 1-day or 2-day payroll"""
    payment_speed: NotRequired[str]
    r"""Payment speed for 1-day, 2-day, 4-day"""


class PaymentConfigs(BaseModel):
    r"""Example response"""

    company_uuid: Optional[str] = None
    r"""Company uuid"""

    partner_uuid: Optional[str] = None
    r"""Partner uuid"""

    fast_payment_limit: Optional[str] = None
    r"""Payment limit for 1-day or 2-day payroll"""

    payment_speed: Optional[str] = None
    r"""Payment speed for 1-day, 2-day, 4-day"""
