"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class Section(str, Enum):
    r"""The document option's section in the list of acceptable documents on the Form I-9"""

    A = "A"
    A1 = "A1"
    A2 = "A2"
    A3 = "A3"
    B = "B"
    C = "C"


class I9AuthorizationDocumentOptionTypedDict(TypedDict):
    r"""An employee's I-9 verification document option based on the authorization status"""

    section: Section
    r"""The document option's section in the list of acceptable documents on the Form I-9"""
    description: str
    r"""The document option's description"""
    document_type: str
    r"""The document option's document type"""
    document_title: List[str]
    r"""The document option's document titles"""
    common_choice: bool
    r"""Whether the document is a common choice for I-9 verification"""


class I9AuthorizationDocumentOption(BaseModel):
    r"""An employee's I-9 verification document option based on the authorization status"""

    section: Section
    r"""The document option's section in the list of acceptable documents on the Form I-9"""

    description: str
    r"""The document option's description"""

    document_type: str
    r"""The document option's document type"""

    document_title: List[str]
    r"""The document option's document titles"""

    common_choice: bool
    r"""Whether the document is a common choice for I-9 verification"""
