"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AdminTypedDict(TypedDict):
    r"""The representation of an admin user in Gusto."""

    uuid: str
    r"""The unique id of the admin."""
    email: NotRequired[str]
    r"""The email of the admin for Gusto's system. If the email matches an existing user, this will create an admin account for them."""
    first_name: NotRequired[str]
    r"""The first name of the admin."""
    last_name: NotRequired[str]
    r"""The last name of the admin."""


class Admin(BaseModel):
    r"""The representation of an admin user in Gusto."""

    uuid: str
    r"""The unique id of the admin."""

    email: Optional[str] = None
    r"""The email of the admin for Gusto's system. If the email matches an existing user, this will create an admin account for them."""

    first_name: Optional[str] = None
    r"""The first name of the admin."""

    last_name: Optional[str] = None
    r"""The last name of the admin."""
