"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutWireInRequestsWireInRequestUUIDRequestBodyTypedDict(TypedDict):
    date_sent: str
    r"""The date the wire was sent"""
    bank_name: str
    r"""Name of the bank sending the wire"""
    amount_sent: str
    r"""Amount of money sent"""
    additional_notes: NotRequired[str]
    r"""Additional notes"""


class PutWireInRequestsWireInRequestUUIDRequestBody(BaseModel):
    date_sent: str
    r"""The date the wire was sent"""

    bank_name: str
    r"""Name of the bank sending the wire"""

    amount_sent: str
    r"""Amount of money sent"""

    additional_notes: Optional[str] = None
    r"""Additional notes"""


class PutWireInRequestsWireInRequestUUIDRequestTypedDict(TypedDict):
    wire_in_request_uuid: str
    r"""The UUID of the Wire In Request"""
    request_body: PutWireInRequestsWireInRequestUUIDRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutWireInRequestsWireInRequestUUIDRequest(BaseModel):
    wire_in_request_uuid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the Wire In Request"""

    request_body: Annotated[
        PutWireInRequestsWireInRequestUUIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""
