"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class VersionHeader(str, Enum):
    TWO_THOUSAND_AND_TWENTY_FOUR_04_01 = "2024-04-01"
