"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "gusto_embedded"
__version__: str = "0.2.0"
__openapi_doc_version__: str = "2024-04-01"
__gen_version__: str = "2.545.4"
__user_agent__: str = "speakeasy-sdk/python 0.2.0 2.545.4 2024-04-01 gusto_embedded"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
