"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .metadata_with_one_entity import (
    MetadataWithOneEntity,
    MetadataWithOneEntityTypedDict,
)
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class MetadataWithMultipleEntitiesTypedDict(TypedDict):
    r"""multiple entities"""

    entities: NotRequired[List[MetadataWithOneEntityTypedDict]]


class MetadataWithMultipleEntities(BaseModel):
    r"""multiple entities"""

    entities: Optional[List[MetadataWithOneEntity]] = None
