"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayrollBlockerTypedDict(TypedDict):
    r"""Example response"""

    key: NotRequired[str]
    r"""The unique identifier of the reason"""
    message: NotRequired[str]
    r"""User-friendly message describing the payroll blocker."""


class PayrollBlocker(BaseModel):
    r"""Example response"""

    key: Optional[str] = None
    r"""The unique identifier of the reason"""

    message: Optional[str] = None
    r"""User-friendly message describing the payroll blocker."""
