"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayrollFixedCompensationTypesTypeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of an available type of fixed compensation."""


class PayrollFixedCompensationTypesType(BaseModel):
    name: Optional[str] = None
    r"""The name of an available type of fixed compensation."""
