"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomFieldType(str, Enum):
    r"""Input type for the custom field."""

    TEXT = "text"
    CURRENCY = "currency"
    NUMBER = "number"
    DATE = "date"
    RADIO = "radio"
