"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EmployeePayStubTypedDict(TypedDict):
    r"""The representation of an employee pay stub information."""

    uuid: str
    r"""The UUID of the employee pay stub."""
    check_date: NotRequired[str]
    r"""The check date of the pay stub."""
    gross_pay: NotRequired[str]
    r"""The gross pay amount for the pay stub."""
    net_pay: NotRequired[str]
    r"""The net pay amount for the pay stub."""
    payroll_uuid: NotRequired[str]
    r"""A unique identifier of the payroll to which the pay stub belongs."""
    check_amount: NotRequired[str]
    r"""The check amount for the pay stub."""


class EmployeePayStub(BaseModel):
    r"""The representation of an employee pay stub information."""

    uuid: str
    r"""The UUID of the employee pay stub."""

    check_date: Optional[str] = None
    r"""The check date of the pay stub."""

    gross_pay: Optional[str] = None
    r"""The gross pay amount for the pay stub."""

    net_pay: Optional[str] = None
    r"""The net pay amount for the pay stub."""

    payroll_uuid: Optional[str] = None
    r"""A unique identifier of the payroll to which the pay stub belongs."""

    check_amount: Optional[str] = None
    r"""The check amount for the pay stub."""
