"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing_extensions import TypedDict


class YtdBenefitAmountsFromDifferentCompanyTypedDict(TypedDict):
    r"""Ytd Benefit Amounts From Different Company"""

    uuid: str
    r"""The unique identifier for this benefit amount record."""
    benefit_type: int
    r"""The benefit type supported by Gusto. See [Benefit Types](https://docs.gusto.com/embedded-payroll/reference/get-v1-benefits) for more information."""
    ytd_employee_deduction_amount: str
    r"""The year-to-date employee deduction made outside the current company."""
    ytd_company_contribution_amount: str
    r"""The year-to-date company contribution made outside the current company."""


class YtdBenefitAmountsFromDifferentCompany(BaseModel):
    r"""Ytd Benefit Amounts From Different Company"""

    uuid: str
    r"""The unique identifier for this benefit amount record."""

    benefit_type: int
    r"""The benefit type supported by Gusto. See [Benefit Types](https://docs.gusto.com/embedded-payroll/reference/get-v1-benefits) for more information."""

    ytd_employee_deduction_amount: str
    r"""The year-to-date employee deduction made outside the current company."""

    ytd_company_contribution_amount: str
    r"""The year-to-date company contribution made outside the current company."""
