"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .employee_benefit_for_company_benefit import (
    EmployeeBenefitForCompanyBenefit,
    EmployeeBenefitForCompanyBenefitTypedDict,
)
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict(
    TypedDict
):
    employee_benefits: List[EmployeeBenefitForCompanyBenefitTypedDict]
    r"""The list of employee benefits to create or update"""


class PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody(BaseModel):
    employee_benefits: List[EmployeeBenefitForCompanyBenefit]
    r"""The list of employee benefits to create or update"""


class PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict(TypedDict):
    company_benefit_id: str
    r"""The UUID of the company benefit"""
    request_body: (
        PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict
    )
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest(BaseModel):
    company_benefit_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the company benefit"""

    request_body: Annotated[
        PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""
