"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TaxSuggestionsTypedDict(TypedDict):
    tax_id: NotRequired[int]
    r"""The ID of the tax."""
    amount: NotRequired[str]
    r"""Calculated tax amount."""


class TaxSuggestions(BaseModel):
    tax_id: Optional[int] = None
    r"""The ID of the tax."""

    amount: Optional[str] = None
    r"""Calculated tax amount."""


class ExternalPayrollTaxSuggestionsTypedDict(TypedDict):
    r"""The representation of an external payroll with minimal information."""

    employee_uuid: NotRequired[str]
    r"""The UUID of the employee."""
    tax_suggestions: NotRequired[List[TaxSuggestionsTypedDict]]
    r"""Possible tax liabilities selections."""


class ExternalPayrollTaxSuggestions(BaseModel):
    r"""The representation of an external payroll with minimal information."""

    employee_uuid: Optional[str] = None
    r"""The UUID of the employee."""

    tax_suggestions: Optional[List[TaxSuggestions]] = None
    r"""Possible tax liabilities selections."""
