"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayScheduleAssignmentEmployeeTypedDict(TypedDict):
    employee_uuid: NotRequired[str]
    r"""The UUID of the employee."""
    pay_schedule_uuid: NotRequired[str]
    r"""The employee's pay schedule UUID."""


class PayScheduleAssignmentEmployee(BaseModel):
    employee_uuid: Optional[str] = None
    r"""The UUID of the employee."""

    pay_schedule_uuid: Optional[str] = None
    r"""The employee's pay schedule UUID."""
