"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UnprocessedTerminationPayPeriodTypedDict(TypedDict):
    r"""The representation of an unprocessed termination pay period."""

    start_date: NotRequired[str]
    r"""The start date of the pay period."""
    end_date: NotRequired[str]
    r"""The end date of the pay period."""
    check_date: NotRequired[str]
    r"""The check date of the pay period."""
    debit_date: NotRequired[str]
    r"""The debit date of the pay period."""
    employee_name: NotRequired[str]
    r"""The full name of the employee."""
    employee_uuid: NotRequired[str]
    r"""A unique identifier of the employee."""
    pay_schedule_uuid: NotRequired[str]
    r"""A unique identifier of the pay schedule to which the pay period belongs."""


class UnprocessedTerminationPayPeriod(BaseModel):
    r"""The representation of an unprocessed termination pay period."""

    start_date: Optional[str] = None
    r"""The start date of the pay period."""

    end_date: Optional[str] = None
    r"""The end date of the pay period."""

    check_date: Optional[str] = None
    r"""The check date of the pay period."""

    debit_date: Optional[str] = None
    r"""The debit date of the pay period."""

    employee_name: Optional[str] = None
    r"""The full name of the employee."""

    employee_uuid: Optional[str] = None
    r"""A unique identifier of the employee."""

    pay_schedule_uuid: Optional[str] = None
    r"""A unique identifier of the pay schedule to which the pay period belongs."""
