"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class I9AuthorizationDocumentTypedDict(TypedDict):
    r"""An employee's I-9 verification document"""

    uuid: str
    r"""The UUID of the I-9 verification document"""
    document_type: str
    r"""The document's document type"""
    document_title: str
    r"""The document's document title"""
    issuing_authority: str
    r"""The document's issuing authority"""
    expiration_date: NotRequired[str]
    r"""The document's expiration date"""


class I9AuthorizationDocument(BaseModel):
    r"""An employee's I-9 verification document"""

    uuid: str
    r"""The UUID of the I-9 verification document"""

    document_type: str
    r"""The document's document type"""

    document_title: str
    r"""The document's document title"""

    issuing_authority: str
    r"""The document's issuing authority"""

    expiration_date: Optional[str] = None
    r"""The document's expiration date"""
