"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .earning_type import EarningType, EarningTypeTypedDict
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class EarningTypeListTypedDict(TypedDict):
    r"""Example response"""

    default: NotRequired[List[EarningTypeTypedDict]]
    r"""The default earning types for the company."""
    custom: NotRequired[List[EarningTypeTypedDict]]
    r"""The custom earning types for the company."""


class EarningTypeList(BaseModel):
    r"""Example response"""

    default: Optional[List[EarningType]] = None
    r"""The default earning types for the company."""

    custom: Optional[List[EarningType]] = None
    r"""The custom earning types for the company."""
