"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DocumentType(str, Enum):
    PRINTABLE_PAYROLL_CHECKS = "printable_payroll_checks"
