"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayScheduleAssignmentTransitionPayPeriodTypedDict(TypedDict):
    r"""Pay schedule assignment transition pay period information."""

    start_date: NotRequired[str]
    r"""Pay period start date."""
    end_date: NotRequired[str]
    r"""Pay period end date."""


class PayScheduleAssignmentTransitionPayPeriod(BaseModel):
    r"""Pay schedule assignment transition pay period information."""

    start_date: Optional[str] = None
    r"""Pay period start date."""

    end_date: Optional[str] = None
    r"""Pay period end date."""
