"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .employee_state_tax_answer import (
    EmployeeStateTaxAnswer,
    EmployeeStateTaxAnswerTypedDict,
)
from .employee_state_tax_input_question_format import (
    EmployeeStateTaxInputQuestionFormat,
    EmployeeStateTaxInputQuestionFormatTypedDict,
)
from gusto_embedded.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class EmployeeStateTaxQuestionTypedDict(TypedDict):
    label: str
    r"""A short title for the question"""
    description: str
    r"""An explaination of the question - this may contain inline html formatted links."""
    key: str
    r"""A unique identifier of the question (for the given state) - used for updating the answer."""
    input_question_format: EmployeeStateTaxInputQuestionFormatTypedDict
    answers: List[EmployeeStateTaxAnswerTypedDict]


class EmployeeStateTaxQuestion(BaseModel):
    label: str
    r"""A short title for the question"""

    description: str
    r"""An explaination of the question - this may contain inline html formatted links."""

    key: str
    r"""A unique identifier of the question (for the given state) - used for updating the answer."""

    input_question_format: EmployeeStateTaxInputQuestionFormat

    answers: List[EmployeeStateTaxAnswer]
